<?php
/***************************************************************************
 *                                                                          *
 *   (c) 2004 Vladimir V. Kalynyak, Alexey V. Vinokurov, Ilya M. Shalnev    *
 *                                                                          *
 * This  is  commercial  software,  only  users  who have purchased a valid *
 * license  and  accept  to the terms of the  License Agreement can install *
 * and use this program.                                                    *
 *                                                                          *
 ****************************************************************************
 * PLEASE READ THE FULL TEXT  OF THE SOFTWARE  LICENSE   AGREEMENT  IN  THE *
 * "copyright.txt" FILE PROVIDED WITH THIS DISTRIBUTION PACKAGE.            *
 ****************************************************************************/

namespace Tygh\Shippings\Services;

//use Procour\Models\DeliveryCosts;
use Tygh\Shippings\IService;
use Tygh\Registry;
use Procour\Client\Client;
use Tygh\Tygh;

class Procour implements IService
{
    protected $client = null;
    protected $weight = null;
    protected $shipping_info;
    /**
     * Procour constructor.
     */
    public function __construct()
    {
        $this->client = new Client();
    }

    public function prepareData($shipping_info)
    {
     	$group_key = $shipping_info['keys']['group_key'];
        $shipping_id = $shipping_info['keys']['shipping_id'];
        $key = trim($shipping_info['service_params']['password']);
		$this->client->setKey($key);
        $this->shipping_info = $shipping_info;
    }

    public function processResponse($response)
    {
        if (isset($this->shipping_info['service_params']['margin_percent']) && is_numeric($this->shipping_info['service_params']['margin_percent'])) {
            $response['cost'] += ($response['cost'] * $this->shipping_info['service_params']['margin_percent']) / 100;
        }
        if (isset($this->shipping_info['service_params']['margin_plus']) && is_numeric($this->shipping_info['service_params']['margin_plus'])) {
            $response['cost'] += $this->shipping_info['service_params']['margin_plus'];
        }
        return $response;
    }

    public function processErrors($response)
    {
        if (!is_array($response) || (isset($response['error']) && $response['error'])) {
            return $response['error'];
        }
        return false;
    }

    public function allowMultithreading()
    {
        return false;
    }

    public function getRequestData()
    {
        return array(
            'method' => 'GET',
            'url' => $this->client->getApiUrl(),
            'data' => array(),
        );
    }

    public function getSimpleRates()
    {
        $response = array(
            'cost' => null,
            'error' => null,
            'delivery_time' => null,
        );
        return $response;
    }
}